#!/bin/sh		# -*- coding: utf-8-unix; -*-
#set -x
#	@(#) Xquartz-script.sh 1.0
#	Time-stamp: <2006-06-16 23:49:29 pete>
#
#############################################################################
#
# Purpose: add some useful applications to launch from X11's menu
# Copyright (C) 2006	Peter Dyballa -- (F)Lawless Software Team, F(l)ST
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
#
#
# Theory of operation
#
# The script first checks whether the user already has a com.apple.x11.plist
# file. If it already exists, then it is saved. Otherwise the "template"
# /etc/X11/xserver/Xquartz.plist is copied, as X11.app would do upon first
# launch. Then a few entries are added that allow to launch useful X clients
# (applications) like xdvi, gv, xpdf, texdoctk (which, to function, would
# need to install the perltk package first), xfig, xv, fontforge, and xkill --
# if they are not yet included: for each of these applications it is first
# checked whether com.apple.x11.plist has it already in its apps_menu array,
# if not, then this entry is made. If no entry had to be made, the copy is
# removed.
#
#############################################################################
#
PlistF=/etc/X11/xserver/Xquartz.plist			# the system's template
PlistT=${HOME}/Library/Preferences/com.apple.x11.plist	# the user's preferences
X11lst=`basename $PlistT .plist`
 Datum=`date "+%+"`
#
if [ -f $PlistT ]; then					# is there already an X11.plist file?
    mv $PlistT "${PlistT}-${Datum}"
    cp "${PlistT}-${Datum}" $PlistT
    origmv=1
#    plutil -convert xml1 $PlistT			# make the file readable
else							# if there's nothing create the minimum
    if [ -f $PlistF ]; then cp $PlistF $PlistT; fi	# if template exists, then copy it
    defaults write $X11lst done_xinit_check -bool true	# make X11 believe that all was checked
#    defaults read $X11lst > /dev/null
    origmv=0
fi
#
defaults read $X11lst apps_menu 2> /dev/null | grep -w xdvi > /dev/null
if [ $? -ne 0 ]; then
    defaults write $X11lst apps_menu -array-add '("View DVI", xdvi, "")'	&& origmv=2
fi
defaults read $X11lst apps_menu 2> /dev/null | grep -w gv > /dev/null
if [ $? -ne 0 ]; then
    defaults write $X11lst apps_menu -array-add '("View PS or PDF", gv, "")'	&& origmv=2
fi
defaults read $X11lst apps_menu 2> /dev/null | grep -w xpdf > /dev/null
if [ $? -ne 0 ]; then
    defaults write $X11lst apps_menu -array-add '("View PDF", xpdf, "")'	&& origmv=2
fi
defaults read $X11lst apps_menu 2> /dev/null | grep -w texdoctk > /dev/null
if [ $? -ne 0 ]; then
    defaults write $X11lst apps_menu -array-add '("View TeX docs", texdoctk, "")' && origmv=2
fi
defaults read $X11lst apps_menu 2> /dev/null | grep -w xfig > /dev/null
if [ $? -ne 0 ]; then
    defaults write $X11lst apps_menu -array-add '("Draw Images", xfig, "")'	&& origmv=2
fi
defaults read $X11lst apps_menu 2> /dev/null | grep -w xv > /dev/null
if [ $? -ne 0 ]; then
    defaults write $X11lst apps_menu -array-add '("View Images", xv, "")'	&& origmv=2
fi
defaults read $X11lst apps_menu 2> /dev/null | grep -w fontforge > /dev/null
if [ $? -ne 0 ]; then
    defaults write $X11lst apps_menu -array-add '("View Fonts", fontforge, "")'	&& origmv=2
fi
defaults read $X11lst apps_menu 2> /dev/null | grep -w xkill > /dev/null
if [ $? -ne 0 ]; then
    defaults write $X11lst apps_menu -array-add '("Kill X client", xkill, "†")'	&& origmv=2
fi
#
if [ $origmv -eq 1 ]; then rm "${PlistT}-${Datum}"; fi	# remove unnecessary copy since nothing's changed
