#!/bin/sh		# -*- coding: iso-8859-15; -*-
#set -x
#	@(#) environment-script.sh 2.0
#	Time-stamp: <2006-12-29 13:06:17 pete>
#
#############################################################################
#
# Purpose: provide search path to MacTeX commands for tcsh and xterm in X11
# Copyright (C) 2006	Peter Dyballa -- (F)Lawless Software Team, F(l)ST
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
#
#
# Theory of operation
#
# The script first checks whether in the user's home directory already a
# directory .MacOSX exists. If not, it is created to later hold the file
# environment.plist. If ~/.MacOSX/environment.plist already exists, its
# contents can be read and parsed to see, whether PATH and MANPATH already are
# OK. In a loop it is first checked whether it contains the path to the regular
# X11 binaries, then the /usr/local/bin component, and finally it is checked
# whether it contains the PATH component to the right TeX binaries. If not,
# each missing component is added. Similarly MANPATH is treated. The script
# remembers whether something was added. If it was, PATH and MANPATH both get
# written back. If any of them did exist before, its original value was
# restored in the for loop by means of the 'default' case, so both can be
# written even if only one value was changed.
# If ~/.MacOSX/environment.plist does neither exist nor contain either a PATH
# or a MANPATH statement, either a very simple ~/.MacOSX/environment.plist
# file is created with just a basic PATH and MANPATH statement or the missing
# contents is added to it.
# The right path to the TeX executables is used here from a variable only,
# because it needs to be expanded, i.e. the (dynamic or) adaptive `uname -p`
# needs to be transformed into a proper 'powerpc' or 'i386' string to be
# useful. This happens in the script's first block of statements. Here the
# also tries to determine where in the world of Mac Geek TeX the latest of
# the manifold of TeX distributions might reside on disk ...
#
#############################################################################
#
# From this simple and almost perfect world ...
#
#TeXbin="/usr/local/teTeX/bin/`uname -p`-apple-darwin-current"
#TeXman="/usr/local/teTeX/man"
#
#  ... we decend into the jungle!
#
if [ -L /usr/texbin ]; then
    TeXbin="/usr/texbin"
     BPfad=`ls -l $TeXbin | awk '{print $NF}'`
     BPfad=`echo $BPfad | awk -F/ '{printf "%s/%s/%s/%s", $1, $2, $3, $4}'`
     MPfad=`basename $BPfad`					# the flavour of TeX ...
else
    echo "No symbolic link /usr/texbin found ..."
     MPfad=`ls -1t /usr/local | grep -i tex | head -1`		# an alternate try, for the most recent!
     BPfad="/usr/local/${MPfad}"
fi
if [ "$MPfad" = "gwTeX" -o "$MPfad" = "teTeX" ]; then		# determine TeX{bin|man}
    TeXman="${BPfad}/man"
    if [ -z "$TeXbin" ]; then
        TeXbin="${BPfad}/bin/`uname -p`-apple-darwin-current"
    fi
elif [ "$MPfad" = "texlive" ]; then				# same for TeX Live
        CC=`date +%C`						# version ${CC}xy
     MPfad=`ls -1 $BPfad | grep $CC | sort`			# get the most recently maintained!
    TeXman=`find ${BPfad}/${MPfad} -type d -name man -ls | awk '{print $NF}'`
    if [ -z "$TeXbin" ]; then
        TeXbin="${BPfad}/${MPfad}/bin/`uname -p`-`uname -s | tr [:upper:] [:lower:]`"
    fi
fi
 Datum=`date "+%+"`
echo ".  ******"
echo ".  Latest TeX executables have been determined to exist in $TeXbin"
echo ".  Latest TeX executables' manual pages have been determined to exist in $TeXman"
echo ".  ******"
echo ".    If that's wrong, then rename the saved original files that now"
echo ".    have the name <original name>-${Datum},"
echo ".    to their original names, and invoke on the command line"
echo ".      sudo touch /usr/local/<correct TeX root>."
echo ".    Then re-run this application!"
echo "   ******"
 Plist="${HOME}/.MacOSX/environment"			# the user's environment.plist
 BPfad="" ; MPfad="" ; X11=0 ; Local=0 ; teTeX=0 ; origmv=0 # they need to be initialised
#
if ! [ -d .MacOSX ]; then mkdir .MacOSX ; fi		# check whether .MacOSX already exists
#
if [ -f ${Plist}.plist ]; then				# is there already a plist file?
#    plutil -convert xml1 ${Plist}.plist			# make the file readable
    Pfad=`defaults read $Plist PATH 2>/dev/null`	# has it PATH?
    if [ -n "$Pfad" ]; then				# check PATH's components, rebuild, and remember
	for Komponente in `echo "$Pfad" | sed -e 's/:/ /g'` ; do
	    case $Komponente in
		/usr/X11R6/bin)	  BPfad="${BPfad}:${Komponente}";   X11=1 ;;
		/usr/local/bin)	  BPfad="${BPfad}:${Komponente}"; Local=1 ;;
		$TeXbin)	  BPfad="${BPfad}:${Komponente}"; teTeX=1 ;;
		*)		  BPfad="${BPfad}:${Komponente}" ;;
	    esac
	done
	if [ $X11   -eq 0 ]; then BPfad="${BPfad}:/usr/X11R6/bin"; fi
	if [ $Local -eq 0 ]; then BPfad="${BPfad}:/usr/local/bin"; fi
	if [ $teTeX -eq 0 ]; then BPfad="${BPfad}:${TeXbin}";	   fi
	 BPfad=`echo $BPfad | sed -e 's/^://'`
	if [[ $teTeX -eq 0 || $Local -eq 0 || $X11 -eq 0 ]]; then
	    origmv=1
	fi
    else
	origmv=1
	 BPfad="${HOME}/bin:/usr/bin:/bin:/usr/X11R6/bin:/usr/local/bin:${TeXbin}"
    fi
####
    if [ $origmv -eq 1 ]; then				# a change is needed
	mv ${Plist}.plist "${Plist}.plist-${Datum}"	# save original since it exists
	cp "${Plist}.plist-${Datum}" ${Plist}.plist	# prepare a copy from the original
    	defaults write $Plist "PATH" $BPfad		# write PATH to environment.plist
    	X11=0 ; Local=0 ; teTeX=0 ; origmv=0		# they need to be re-initialised
    fi
####
    Pfad=`defaults read $Plist MANPATH 2>/dev/null`	# has it MANPATH?
    if [ -n "$Pfad" ]; then				# check MANPATH's components, rebuild, and remember
	for Komponente in `echo "$Pfad" | sed -e 's/:/ /g'` ; do
	    case $Komponente in
		/usr/X11R6/man)	  MPfad="${MPfad}:${Komponente}";   X11=1 ;;
		/usr/local/man)	  MPfad="${MPfad}:${Komponente}"; Local=1 ;;
		$TeXman)	  MPfad="${MPfad}:${Komponente}"; teTeX=1 ;;
		*)		  MPfad="${MPfad}:${Komponente}" ;;
	    esac
	done
	if [ $X11   -eq 0 ]; then MPfad="${MPfad}:/usr/X11R6/man"; fi
	if [ $Local -eq 0 ]; then MPfad="${MPfad}:/usr/local/man"; fi
	if [ $teTeX -eq 0 ]; then MPfad="${MPfad}:${TeXman}";	   fi
	 MPfad=`echo $MPfad | sed -e 's/^://'`
	if [[ $teTeX -eq 0 || $Local -eq 0 || $X11 -eq 0 ]]; then
	    origmv=`expr $origmv + 1`
	fi
    else
	origmv=`expr $origmv + 1`
	 MPfad="/usr/share/man:/usr/X11R6/man:/usr/local/man:${TeXman}"
    fi
####
    case $origmv in
	2) defaults write $Plist "MANPATH" $MPfad ;;	# write MANPATH to environment.plist
	1) mv ${Plist}.plist "${Plist}.plist-${Datum}"	# save original since it exists
	   cp "${Plist}.plist-${Datum}" ${Plist}.plist	# prepare a copy from the original
	   defaults write $Plist "MANPATH" $MPfad ;;	# write MANPATH to environment.plist
	*) ;;						# no change needed
    esac
####
else							# create the minimum
    defaults write $Plist "PATH"    "${HOME}/bin:/usr/bin:/bin:/usr/X11R6/bin:/usr/local/bin:${TeXbin}"
    defaults write $Plist "MANPATH" "/usr/share/man:/usr/X11R6/man:/usr/local/man:${TeXman}"
fi
