#!/bin/sh		# -*- coding: iso-8859-15; -*-
#set -x
#	@(#) xinitrc-script.sh 1.0
#	Time-stamp: <2006-12-26 21:12:13 pete>
#
#############################################################################
#
# Purpose: provide search path for MacTeX applications in an X11 environment
# Copyright (C) 2006	Peter Dyballa -- (F)Lawless Software Team, F(l)ST
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2 of the License, or (at your
# option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
#
#
# Theory of operation
#
# The script first checks whether a file .xinitrc in the user's home directory
# (~, $HOME) already exists. If so, it checks whether it already has statements
# that write or delete a DISPLAY entry (there is not much sense for it in
# another plist file). These statements are checked whether they are the right
# ones by deleting all white space and removing those lines from the list that
# start with a '#', i.e. are commented out from being executed. The remainder
# is sorted and made to comprise only unique entries. These are finally
# counted. In the ideal case they are two and nothing needs to be done, but the
# lines need to be checked by the user whether they are right for our purpose.
# If the .xinitrc file does not contain these lines first a good place for the
# 'defaults write' action to insert is searched, an empty line before the first
# X client is launched. This line's number must be greater than that of the
# empty line to have DISPLAY set in ~/.MacOSX/environment.plist early enough.
# If this condition is not met, the 'defaults write' action will be inserted at
# the second line. Once during its execution .xinitrc has recorded a DISPLAY
# entry in ~/.MacOSX/environment.plist it needs to be removed when this X11
# session ends, because the next session might use a different value. So the
# last line executed in .xinitrc is determined, by which the window manager is
# usually launched (this has the advantage that the X server shuts down when
# the window manager is exit; a login session in xterm can achieve the same).
# This line can be a line with 'exec <something>' or it can be a simple
# '<application with parameters>' to which the right change statement needs to
# be found. In the latter case a simple 'defaults delete' statement is added to
# it to create kind of a 'compound statement', in the other case a more
# different 'compound statement' is created. It is not directly this script
# that edits .xinitrc, but it's sed. So all the edit instructions are saved in
# a sed script. This shell script determines whether it needs to edit an
# existing .xinitrc file or whether a system template needs to be adapted for
# MacTeX use. In the latter case it uses a pre-configured sed script.
#
#############################################################################
#
ShlHom="$1"
 Datum=`date "+%+"`
#
if [ -f .xinitrc ]; then				# is there already .xinitrc?
    Anzahl=`egrep 'defaults[ 	]+(write|delete)[ 	]+.*DISPLAY' .xinitrc | \
		tr -d '	 ' | grep -v '^#' | sort -u | wc -l`	# are there already the statements?
###	     or tr -d '[:blank:]'?
    if [ $Anzahl -ne 2 ]; then
        Zeile1=`grep -n '^$' .xinitrc | head -1 | tr -d :`	# first empty line
        Zeile2=`grep -n '&' .xinitrc | tr -d ' 	' | grep -v ':#' | head -1 | sed -e 's/:.*$//'`	# first X client
        if [[ -n "$Zeile1" && $Zeile2 -gt $Zeile1 ]]; then	# empty line before the first X client is launched?
    	    Zeile=$Zeile1				# use this empty line's number
        else
    	    Zeile=2					# put it right after '#!/bin/sh'
        fi
	echo "${Zeile}i\\" > xinitrc.sed
	echo "defaults write \${HOME}/.MacOSX/environment \"DISPLAY\" \$DISPLAY" >> xinitrc.sed
#
        Zeile3=`grep -nw exec .xinitrc | egrep -v '#|&' | head -1 | sed -e 's/:.*$//'`	# first 'exec' X client or Window Manager
        Zeile4=`egrep -n '[^&]$' .xinitrc | grep -v '#' | tail -1 | sed -e 's/:.*$//'`	# last X client or Window Manager
        if [ -n "$Zeile3" ]; then
    	    echo "${Zeile3}s/^exec \(.*$\)/( \1 ; defaults delete \${HOME}\/.MacOSX\/environment \"DISPLAY\" )/" >> xinitrc.sed
	else
    	    echo "${Zeile4}s/^\(.*\)$/( \1 ; defaults delete \${HOME}\/.MacOSX\/environment \"DISPLAY\" )/" >> xinitrc.sed
        fi
        mv   .xinitrc ".xinitrc-${Datum}"		# save the original .xinitrc script
        cat ".xinitrc-${Datum}" | sed -f xinitrc.sed > .xinitrc	# use the sed script just created
	rm xinitrc.sed					# for cleaning
    else
	echo "..===================================================================="
	echo "... Please check your ~/.xinitrc file for correctness!"
	echo "... It could not be exactly determined whether your ~/.xinitrc file"
	echo "... correctly edits your ~/.MacOSX/environment.plist as needed for"
	echo "... MacTeX and X11."
	echo "..===================================================================="
	exit 1
    fi
else							# if not fetch and edit the system template
    if [ -f /etc/X11/xinit/xinitrc ]; then		# does the template exist
	cat /etc/X11/xinit/xinitrc | sed -f "${ShlHom}/no_xinitrc.sed" > .xinitrc
    else
	echo "..===================================================================="
	echo "... Big failure!"
	echo "... The template file /etc/X11/xinit/xinitrc for your own ~/.xinitrc"
	echo "... file is missing. X11 and MacTeX won't be able to co-operate!"
	echo "..===================================================================="
	exit 2
    fi
fi
